/**************************************************************
  (C) 1997 by Achim Kaiser

  You may distribute under the terms of the GNU General Public
  License as specified in the COPYING file.
**************************************************************/

#ifndef SHELLGUI_H
#define SHELLGUI_H

void ShellWindowInit(int nof);

void ShellWindowInfo(char *namet,char *names,char *named,int this);

int ShellWindowUpdate();

int ShellWindowDoIt(char** argv,int cont,char *path);

void ShellWindowDestroy();

#endif

